{% extends 'base.html' %}

{% block page_meta_title %}
    Not Found - {{ request.site.name }}
{% endblock %}

{% block content %}

    <h1>Error 404</h1>
    
    <p>The page that you requested was not found on this server.</p>

{% endblock %}
